#ifndef GRS_GRS_H
#define GRS_GRS_H

#include <grs/main.h>
#include <grs/property.h>
#include <grs/buttonbox.h>
#include <grs/valuelist.h>

#include <grs/filebutton.h>
#include <grs/funcbutton.h>
#include <grs/threadbutton.h>
#include <grs/togglebutton.h>
#include <grs/windowbutton.h>

#include <grs/entryint.h>
#include <grs/entryreal.h>

#include <grs/graph.h>
#include <grs/graphcanvas.h>
#include <grs/graphstream.h>

#endif
